@@ -1,31 +1,7 @@
-package Package::Subroutine;
-# **************************
-use strict; use warnings;
-our $VERSION = 'v0.23.1';
-# ***********************
-; no strict 'refs'
-
-; use Class::ISA ()
-
-; sub export_to_caller
-    { my ($self,$level) = @_
-    ; my $namespace = (caller($level))[0]
-    ; return sub
-      { my ($from,@methods) = @_
-      ; $from = caller if $from eq '_'
-      ; exporter($namespace,$from,@methods)
-      }
-    }
-
-; sub export_to
-    { my ($self,$namespace) = @_
-    ; return sub
-        { my ($from,@methods) = @_
-        ; $from = caller if $from eq '_'
-        ; exporter($namespace,$from,@methods)
-        }
-    }
-
+  package Package::Subroutine
+# ***************************
+; our $VERSION = '0.14'
+# *********************
 ; sub export
     { my $ns = (caller(1))[0]
     ; shift() # rm package
@@ -44,7 +20,7 @@ our $VERSION = 'v0.23.1';
     { my $ns  = (caller(0))[0]
     ; my $pkg = shift()
     ; if(@_==1)
-        { push @_, $pkg->findsubs($_[0])
+        { push @_, $pkg->findsubs($ns)
         }
     ; exporter($ns,@_)
     }
@@ -58,6 +34,7 @@ our $VERSION = 'v0.23.1';
     ; for ( @methods )
         { my $srcm = my $trgm = $_
         ; ($srcm,$trgm) = @$_ if ref eq 'ARRAY'
+
         ; my $target = "${namespace}::${trgm}"
         ; my $source = "${from}::${srcm}"
         ; *$target = \&$source
@@ -78,7 +55,7 @@ our $VERSION = 'v0.23.1';
    ; $target="${target}::${name}"
    ; *$target = $coderef
    }
-
+   
 ; sub isdefined
    { my ($pkg,$namespace,$subname)=@_
    ; unless($subname)
@@ -88,20 +65,12 @@ our $VERSION = 'v0.23.1';
        }
    ; *{"${namespace}::${subname}"}{CODE} || undef
    }
-
+   
 ; sub findsubs
    { my ($self,$class)=@_
    ; grep { *{"${class}::${_}"}{CODE} } keys %{"${class}::"}
    }
 
-; sub findmethods
-   { my ($self,$class)=@_
-   ; my %methods = map { $_ => 1 }
-       map { $self->findsubs($_) }
-       reverse  (Class::ISA::self_and_super_path($class),'UNIVERSAL')
-   ; return keys %methods
-   }
-
 ; 1
 
 __END__
@@ -129,13 +98,6 @@ And you can build a relay for your subroutines.
    ; sub import
        { export Package::Subroutine FooModule => qw/foo fun/
        ; export Package::Subroutine BarPackage => qw/bar geld/
-       ; do_export()
-       }
-
-To export not directly from import the method export_to_caller exists.
-
-   ; sub do_export
-       { export_to_caller Package::Subroutine(2)->('_' => 'mystuff')
        }
 
 And you can get and compare version numbers with this module.
@@ -161,7 +123,7 @@ As a helper exists a method which lists all subroutines in a package.
 =head2 C<import,mixin and export>
 
 This module provides two class methods to transfer subs
-from one namespace into another. C<mixin> is an alias for
+from one namespace into another. C<mixin> is an alias for 
 import with the addition to import all subroutines from a namespace.
 
 The way this module works is very simple, so it is possible that it does not work
@@ -170,20 +132,20 @@ go wrong. You are also free to use the long time available
 and stable alternatives. Anyway I hope this package finds its
 ecological niche.
 
-A possible use case for this module is an situation where a package
-decides during load time from where the used functions come from.
-In such a case Exporter is not a good solution because it
-is bound to C<use> and C<@ISA> what makes things a little bit
-harder to change.
+A possible use case for this module is an situation where a package 
+decides during load time from where the used functions come from. 
+In such a case Exporter is not a good solution because it 
+is bound to C<use> and C<@ISA> what made things a little bit 
+harder to change things dynamically. 
 
 The inport or export needs at least two arguments. The first is a
 package name. Second argument is a list of function names.
 
-It is safest, if the package was loaded before you transfer the subs
-around.
+It is safest, if the package was loaded before you transfer the subs 
+around. 
 
-There is a shortcut for the current namespace included because
-you shouldn't write
+There is a shortcut for the current namespace included because 
+you can't write
 
    export Package::Subroutine __PACKAGE__ => qw/foo bar/
 
@@ -192,8 +154,8 @@ namespace and this is seldom what you want. Please use the form
 from synopsis with one underscore, when the current package is
 the source for the subroutines.
 
-You can change the name of the sub in the target namespace. To do so,
-you give a array reference with the sourcename and the targetname
+You can change the name of the sub in the target namespace. To do so, 
+you give a array reference with the sourcename and the targetname 
 instead of the plain string name.
 
   package Here;
@@ -203,25 +165,12 @@ instead of the plain string name.
 
   import Package::Subroutine There => [wild => 'wilder'];
   # and There::wild -> Here::wilder
-
+  
 The purpose of mixin is that your code can distinguish between
 functions and methods. The convention I suggest is to use C<mixin>
-for methods and C<import> for the rest. Calling mixin without the list
+for methods and C<import> for the rest. Calling mixin without the list 
 of method names imports all subs from the given namespace.
 
-=head2 C<export_to_caller>
-
-This method takes the level for the caller function call and returns a code
-reference which wraps the C<exporter> function curried with the specified
-target namespace.
-
-=head2 C<export_to>
-
-The right tool to export subroutines into an arbitrary namespace. The
-argument here is a package name, the target for the export. It works like
-C<export_to_caller> and returns a code reference. These should be called with
-the source namespace and the subroutine names.
-
 =head2 C<exporter>
 
 The methods above are using one function. This function is usable with full
@@ -256,23 +205,24 @@ or a pair of package name and function name.
 This method returns a list or an array with all defined functions
 for a given package.
 
-=head2 C<findmethods>
-
-Simliar to findsubs but reads all classes in C<@ISA> plus UNIVERSAL.
-L<Class::ISA> is used for the task to list all subclasses.
-
 =head1 Note
 
 I know this package does not much, what is not possible with core
 functionality or other CPAN modules. But for me it seems to make some
 things easier to type and hopefully the code a little bit more
-readable.
+readable.  
 
 =head2 Other helper packages
 
 =over 4
 
-=item L<Package::Subroutine::Namespace>
+=item L<Package::Subroutine::ISA>
+
+=item L<Package::Subroutine::Object>
+
+=item L<Package::Subroutine::Function>
+
+=item L<Package::Subroutine::Functions>
 
 =item L<Package::Subroutine::Sugar>
 
@@ -286,10 +236,6 @@ readable.
 
 =item L<Exporter>
 
-=item L<Class::Inspector>
-
-The C<methods> method has much more features than findmethods.
-
 =back
 
 =head1 CONTRIBUTIONS
@@ -303,5 +249,5 @@ should happen anyway.)
 Perl has a free license, so this module shares it with this
 programming language.
 
-Copyleft 2006-2012 by Sebastian Knapp E<lt>rock@ccls-online.deE<gt>
+Copyleft 2006-2009 by Sebastian Knapp E<lt>rock@ccls-online.deE<gt>
 
